//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/ba3d/def.h
//! @brief     Definitions in namespace GUI::RealSpace
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_BA3D_DEF_H
#define BORNAGAIN_GUI_BA3D_DEF_H

#if defined(__GNUC__) && !defined(__APPLE__)
#pragma GCC diagnostic ignored "-Wswitch-enum"
#pragma GCC diagnostic ignored "-Wpadded"
#pragma GCC diagnostic ignored "-Wfloat-equal"
#endif

#include <QVector3D>

namespace GUI::RealSpace {

// coordinates
struct F3 {
    float x, y, z;

    F3();
    F3(float);
    F3(float, float, float);

    F3(QVector3D const&);
    operator QVector3D() const;

    float length() const;
    F3 normalized() const;

    F3 interpolateTo(const F3&, float) const;

    static F3 const _0, _1, _x, _y, _z;
};

// products
F3 cross(const F3&, const F3&);
float dot(const F3&, const F3&);

F3 operator+(const F3&);
F3 operator-(const F3&);
F3 operator*(const F3&, float);

F3 operator+(const F3&, const F3&);
F3 operator-(const F3&, const F3&);

//! Range of float
struct Range {
    float min, max;
    Range(float, float);

    float size() const;
    float mid() const;
};

//! Range of coordinates
struct VectorRange {
    Range x, y, z;
    VectorRange(Range, Range, Range);
    VectorRange(F3, F3);

    F3 size() const;
    F3 mid() const;

    float length() const;
};

} // namespace GUI::RealSpace

#endif // BORNAGAIN_GUI_BA3D_DEF_H
