//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/ba3d/model/object.h
//! @brief     Defines Object class
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_BA3D_MODEL_OBJECT_H
#define BORNAGAIN_GUI_BA3D_MODEL_OBJECT_H

#include "GUI/ba3d/model/geometry_inc.h"
#include <QColor>
#include <QMatrix4x4>

namespace GUI::RealSpace {

class Model;
class Canvas;

//! A geometric object
class Object {
    friend class Model;

public:
    Object(GeometricID::Key);
    virtual ~Object();

    QColor color;

    void transform(float scale, F3 rotate, F3 translate);
    void transform(F3 scale, F3 rotate, F3 translate);
    void transform(F3 scale, QQuaternion, F3 translate);
    void transform(F3 turn, F3 scale, F3 rotate, F3 translate);

    void addExtrinsicRotation(F3 turn, F3 scale, F3& rotate, F3 rotateExtrinsic, F3& translate);

protected:
    bool isNull;

private:
    Model* model;

    GeometricID::Key gky;
    GeometryHandle geo;     // retrieved on demand
    void releaseGeometry(); // can be released whenever

    QMatrix4x4 mat;
    void draw(Canvas&);
};

} // namespace GUI::RealSpace

#endif // BORNAGAIN_GUI_BA3D_MODEL_OBJECT_H
