
// File: index.xml

// File: classAlphaScan.xml
%feature("docstring") AlphaScan "

Scan type with inclination angles as coordinate values and a unique wavelength. Features footprint correction.

C++ includes: AlphaScan.h
";

%feature("docstring")  AlphaScan::AlphaScan "AlphaScan::AlphaScan(double wl, std::vector< double > inc_angle)
AlphaScan::AlphaScan";

%feature("docstring")  AlphaScan::AlphaScan "AlphaScan::AlphaScan(double wl, const IAxis &inc_angle)
AlphaScan::AlphaScan";

%feature("docstring")  AlphaScan::AlphaScan "AlphaScan::AlphaScan(double wl, int nbins, double alpha_i_min, double alpha_i_max)
AlphaScan::AlphaScan
Sets angle-defined specular scan. The first parameter is always a wavelength in nm. Second parameter is either a numpy array of incident angles in radians or an IAxis object with angle values. Alternatively an axis can be defined in-place, then the second passed parameter is the number of bins, third - minimum on-axis angle value, fourth - maximum on-axis angle value. 
";

%feature("docstring")  AlphaScan::~AlphaScan "AlphaScan::~AlphaScan() override
AlphaScan::~AlphaScan";

%feature("docstring")  AlphaScan::clone "AlphaScan * AlphaScan::clone() const override
AlphaScan::clone";

%feature("docstring")  AlphaScan::generateElements "std::vector< SpecularElement > AlphaScan::generateElements() const override
AlphaScan::generateElements
Generates simulation elements for specular simulations. 
";

%feature("docstring")  AlphaScan::coordinateAxis "const IAxis * AlphaScan::coordinateAxis() const override
AlphaScan::coordinateAxis
Returns coordinate axis assigned to the data holder. 
";

%feature("docstring")  AlphaScan::footprintFactor "const IFootprintFactor * AlphaScan::footprintFactor() const override
AlphaScan::footprintFactor
Returns IFootprintFactor object pointer. 
";

%feature("docstring")  AlphaScan::footprint "std::vector< double > AlphaScan::footprint(size_t start, size_t n_elements) const override
AlphaScan::footprint
Returns footprint correction factor for a range of simulation elements of size  n_elements and starting from element with index  i. 
";

%feature("docstring")  AlphaScan::numberOfElements "size_t AlphaScan::numberOfElements() const override
AlphaScan::numberOfElements
Returns the number of simulation elements. 
";

%feature("docstring")  AlphaScan::createCoordSystem "CoordSystem1D * AlphaScan::createCoordSystem() const override
AlphaScan::createCoordSystem";

%feature("docstring")  AlphaScan::createIntensities "std::vector< double > AlphaScan::createIntensities(const std::vector< SpecularElement > &eles) const override
AlphaScan::createIntensities
Returns intensity vector corresponding to convolution of given simulation elements. 
";

%feature("docstring")  AlphaScan::wavelengthResolution "const ScanResolution * AlphaScan::wavelengthResolution() const
AlphaScan::wavelengthResolution";

%feature("docstring")  AlphaScan::angleResolution "const ScanResolution * AlphaScan::angleResolution() const
AlphaScan::angleResolution";

%feature("docstring")  AlphaScan::wavelength "double AlphaScan::wavelength() const override
AlphaScan::wavelength";

%feature("docstring")  AlphaScan::setFootprintFactor "void AlphaScan::setFootprintFactor(const IFootprintFactor *f_factor)
AlphaScan::setFootprintFactor
Sets footprint correction factor. 
";

%feature("docstring")  AlphaScan::setWavelengthResolution "void AlphaScan::setWavelengthResolution(const ScanResolution &resolution)
AlphaScan::setWavelengthResolution
Sets wavelength resolution values via  ScanResolution object. 
";

%feature("docstring")  AlphaScan::setRelativeWavelengthResolution "void AlphaScan::setRelativeWavelengthResolution(const IRangedDistribution &distr, double rel_dev)
AlphaScan::setRelativeWavelengthResolution";

%feature("docstring")  AlphaScan::setRelativeWavelengthResolution "void AlphaScan::setRelativeWavelengthResolution(const IRangedDistribution &distr, const std::vector< double > &rel_dev)
AlphaScan::setRelativeWavelengthResolution
Sets wavelength resolution values via IRangedDistribution and values of relative deviations (that is,  rel_dev equals standard deviation divided by the mean value).  rel_dev can be either single-valued or a numpy array. In the latter case the length of the array should coinside with the length of the inclination angle axis. 
";

%feature("docstring")  AlphaScan::setAbsoluteWavelengthResolution "void AlphaScan::setAbsoluteWavelengthResolution(const IRangedDistribution &distr, double std_dev)
AlphaScan::setAbsoluteWavelengthResolution";

%feature("docstring")  AlphaScan::setAbsoluteWavelengthResolution "void AlphaScan::setAbsoluteWavelengthResolution(const IRangedDistribution &distr, const std::vector< double > &std_dev)
AlphaScan::setAbsoluteWavelengthResolution
Sets wavelength resolution values via IRangedDistribution and values of standard deviations.  std_dev can be either single-valued or a numpy array. In the latter case the length of the array should coinside with the length of the inclination angle axis. 
";

%feature("docstring")  AlphaScan::setAngleResolution "void AlphaScan::setAngleResolution(const ScanResolution &resolution)
AlphaScan::setAngleResolution
Sets angle resolution values via  ScanResolution object. 
";

%feature("docstring")  AlphaScan::setRelativeAngularResolution "void AlphaScan::setRelativeAngularResolution(const IRangedDistribution &distr, double rel_dev)
AlphaScan::setRelativeAngularResolution";

%feature("docstring")  AlphaScan::setRelativeAngularResolution "void AlphaScan::setRelativeAngularResolution(const IRangedDistribution &distr, const std::vector< double > &rel_dev)
AlphaScan::setRelativeAngularResolution
Sets angular resolution values via IRangedDistribution and values of relative deviations (that is,  rel_dev equals standard deviation divided by the mean value).  rel_dev can be either single-valued or a numpy array. In the latter case the length of the array should coinside with the length of the inclination angle axis. 
";

%feature("docstring")  AlphaScan::setAbsoluteAngularResolution "void AlphaScan::setAbsoluteAngularResolution(const IRangedDistribution &distr, double std_dev)
AlphaScan::setAbsoluteAngularResolution";

%feature("docstring")  AlphaScan::setAbsoluteAngularResolution "void AlphaScan::setAbsoluteAngularResolution(const IRangedDistribution &distr, const std::vector< double > &std_dev)
AlphaScan::setAbsoluteAngularResolution
Sets angular resolution values via IRangedDistribution and values of standard deviations.  std_dev can be either single-valued or a numpy array. In the latter case the length of the array should coinside with the length of the inclination angle axis. 
";


// File: classChi2Metric.xml
%feature("docstring") Chi2Metric "

Implementation of the standard  $ \\\\chi^2 $ metric derived from maximum likelihood with Gaussian uncertainties. With default L2 norm corresponds to the formula  \\\\[\\\\chi^2 = \\\\sum \\\\frac{(I - D)^2}{\\\\delta_D^2}\\\\]

C++ includes: ObjectiveMetric.h
";

%feature("docstring")  Chi2Metric::Chi2Metric "Chi2Metric::Chi2Metric()
Chi2Metric::Chi2Metric";

%feature("docstring")  Chi2Metric::clone "Chi2Metric * Chi2Metric::clone() const override
Chi2Metric::clone";

%feature("docstring")  Chi2Metric::computeFromArrays "double Chi2Metric::computeFromArrays(std::vector< double > sim_data, std::vector< double > exp_data, std::vector< double > exp_stdv, std::vector< double > weight_factors) const override
Chi2Metric::computeFromArrays
Computes metric value from data arrays. Negative values in exp_data are ignored as well as non-positive weight_factors and uncertainties. All arrays involved in the computation must be of the same size.

Parameters:
-----------

sim_data: 
array with simulated intensities.

exp_data: 
array with intensity values obtained from an experiment.

exp_stdv: 
array with experimental data uncertainties.

weight_factors: 
user-defined weighting factors. Used linearly, no matter which norm is chosen. 
";

%feature("docstring")  Chi2Metric::computeFromArrays "double Chi2Metric::computeFromArrays(std::vector< double > sim_data, std::vector< double > exp_data, std::vector< double > weight_factors) const override
Chi2Metric::computeFromArrays
Computes metric value from data arrays. Negative values in exp_data are ignored as well as non-positive weight_factors. All arrays involved in the computation must be of the same size.

Parameters:
-----------

sim_data: 
array with simulated intensities.

exp_data: 
array with intensity values obtained from an experiment.

weight_factors: 
user-defined weighting factors. Used linearly, no matter which norm is chosen. 
";


// File: classChiModuleWrapper.xml
%feature("docstring") ChiModuleWrapper "

Metric wrapper for back-compaptibility with old scripts. 
";

%feature("docstring")  ChiModuleWrapper::ChiModuleWrapper "ChiModuleWrapper::ChiModuleWrapper(std::unique_ptr< IChiSquaredModule > module)
ChiModuleWrapper::ChiModuleWrapper";

%feature("docstring")  ChiModuleWrapper::compute "double ChiModuleWrapper::compute(const std::vector< SimDataPair > &fit_objects, size_t n_pars) const override
ChiModuleWrapper::compute";


// File: classChiSquaredModule.xml
%feature("docstring") ChiSquaredModule "

Calculation of chi2 between two data sets.

C++ includes: ChiSquaredModule.h
";

%feature("docstring")  ChiSquaredModule::ChiSquaredModule "ChiSquaredModule::ChiSquaredModule()=default
ChiSquaredModule::ChiSquaredModule";

%feature("docstring")  ChiSquaredModule::ChiSquaredModule "ChiSquaredModule::ChiSquaredModule(const ChiSquaredModule &other)=default
ChiSquaredModule::ChiSquaredModule";

%feature("docstring")  ChiSquaredModule::~ChiSquaredModule "ChiSquaredModule::~ChiSquaredModule() override=default
ChiSquaredModule::~ChiSquaredModule";

%feature("docstring")  ChiSquaredModule::clone "ChiSquaredModule * ChiSquaredModule::clone() const override
ChiSquaredModule::clone
clone method 
";

%feature("docstring")  ChiSquaredModule::residual "double ChiSquaredModule::residual(double a, double b, double weight) override
ChiSquaredModule::residual";


// File: classComponentKeyHandler.xml
%feature("docstring") ComponentKeyHandler "

Stores INode instances, associates them with given tag, and provides unique keys.

C++ includes: ComponentKeyHandler.h
";

%feature("docstring")  ComponentKeyHandler::insertModel "void ComponentKeyHandler::insertModel(const std::string &tag, const INode *s)
ComponentKeyHandler::insertModel";

%feature("docstring")  ComponentKeyHandler::objectsOfType "std::vector< const T * > ComponentKeyHandler::objectsOfType() const
ComponentKeyHandler::objectsOfType";

%feature("docstring")  ComponentKeyHandler::obj2key "std::string ComponentKeyHandler::obj2key(const INode *s) const
ComponentKeyHandler::obj2key";


// File: classComputationStatus.xml
%feature("docstring") ComputationStatus "

Completion status (flag and text) of a numeric computation.

C++ includes: ComputationStatus.h
";

%feature("docstring")  ComputationStatus::ComputationStatus "ComputationStatus::ComputationStatus()
ComputationStatus::ComputationStatus";

%feature("docstring")  ComputationStatus::isCompleted "bool ComputationStatus::isCompleted() const
ComputationStatus::isCompleted";

%feature("docstring")  ComputationStatus::errorMessage "std::string ComputationStatus::errorMessage() const
ComputationStatus::errorMessage";

%feature("docstring")  ComputationStatus::setRunning "void ComputationStatus::setRunning()
ComputationStatus::setRunning";

%feature("docstring")  ComputationStatus::setCompleted "void ComputationStatus::setCompleted()
ComputationStatus::setCompleted";

%feature("docstring")  ComputationStatus::setFailed "void ComputationStatus::setFailed(const std::string &message)
ComputationStatus::setFailed";


// File: classConstantBackground.xml
%feature("docstring") ConstantBackground "

Constant background, to be added to simulated scattering.

C++ includes: ConstantBackground.h
";

%feature("docstring")  ConstantBackground::ConstantBackground "ConstantBackground::ConstantBackground(std::vector< double > P)
ConstantBackground::ConstantBackground";

%feature("docstring")  ConstantBackground::ConstantBackground "ConstantBackground::ConstantBackground(double background_value)
ConstantBackground::ConstantBackground";

%feature("docstring")  ConstantBackground::clone "ConstantBackground * ConstantBackground::clone() const override
ConstantBackground::clone";

%feature("docstring")  ConstantBackground::className "std::string ConstantBackground::className() const final
ConstantBackground::className";

%feature("docstring")  ConstantBackground::parDefs "std::vector< ParaMeta > ConstantBackground::parDefs() const final
ConstantBackground::parDefs";

%feature("docstring")  ConstantBackground::backgroundValue "double ConstantBackground::backgroundValue() const
ConstantBackground::backgroundValue";

%feature("docstring")  ConstantBackground::addBackground "double ConstantBackground::addBackground(double intensity) const override
ConstantBackground::addBackground";

%feature("docstring")  ConstantBackground::validate "std::string ConstantBackground::validate() const override
ConstantBackground::validate";


// File: classDepthProbeComputation.xml
%feature("docstring") DepthProbeComputation "

Performs a single-threaded depth probe computation with given sample.

Controlled by the multi-threading machinery in ISimulation::runSingleSimulation().

C++ includes: DepthProbeComputation.h
";

%feature("docstring")  DepthProbeComputation::DepthProbeComputation "DepthProbeComputation::DepthProbeComputation(const ReSample &re_sample, const SimulationOptions &options, ProgressHandler &progress, DepthProbeElementIter begin_it, DepthProbeElementIter end_it)
DepthProbeComputation::DepthProbeComputation";

%feature("docstring")  DepthProbeComputation::~DepthProbeComputation "DepthProbeComputation::~DepthProbeComputation() override
DepthProbeComputation::~DepthProbeComputation";


// File: classDepthProbeSimulation.xml
%feature("docstring") DepthProbeSimulation "

Simulation of radiation depth profile.

Holds an instrument and sample model. Computes radiation intensity as function of incoming glancing angle and penetration depth. Scattered rays are neglected. Only refraction, reflection and attenuation of the incoming beam are accounted for.

C++ includes: DepthProbeSimulation.h
";

%feature("docstring")  DepthProbeSimulation::DepthProbeSimulation "DepthProbeSimulation::DepthProbeSimulation(const MultiLayer &sample)
DepthProbeSimulation::DepthProbeSimulation";

%feature("docstring")  DepthProbeSimulation::~DepthProbeSimulation "DepthProbeSimulation::~DepthProbeSimulation() override
DepthProbeSimulation::~DepthProbeSimulation";

%feature("docstring")  DepthProbeSimulation::className "std::string DepthProbeSimulation::className() const final
DepthProbeSimulation::className";

%feature("docstring")  DepthProbeSimulation::nodeChildren "std::vector< const INode * > DepthProbeSimulation::nodeChildren() const override
DepthProbeSimulation::nodeChildren";

%feature("docstring")  DepthProbeSimulation::setBeamParameters "void DepthProbeSimulation::setBeamParameters(double lambda, int nbins, double alpha_i_min, double alpha_i_max, const IFootprintFactor *beam_shape=nullptr)
DepthProbeSimulation::setBeamParameters
Sets beam parameters with alpha_i of the beam defined in the range. 
";

%feature("docstring")  DepthProbeSimulation::setZSpan "void DepthProbeSimulation::setZSpan(size_t n_bins, double z_min, double z_max)
DepthProbeSimulation::setZSpan
Set z positions for intensity calculations. Negative z's correspond to the area under sample surface. The more negative z is, the deeper layer corresponds to it. 
";

%feature("docstring")  DepthProbeSimulation::alphaAxis "const IAxis * DepthProbeSimulation::alphaAxis() const
DepthProbeSimulation::alphaAxis
Returns a pointer to incident angle axis. 
";

%feature("docstring")  DepthProbeSimulation::zAxis "const IAxis * DepthProbeSimulation::zAxis() const
DepthProbeSimulation::zAxis
Returns a pointer to z-position axis. 
";

%feature("docstring")  DepthProbeSimulation::force_polarized "bool DepthProbeSimulation::force_polarized() const override
DepthProbeSimulation::force_polarized
Force polarized computation even in absence of sample magnetization or external fields. 
";

%feature("docstring")  DepthProbeSimulation::initDistributionHandler "void DepthProbeSimulation::initDistributionHandler() override
DepthProbeSimulation::initDistributionHandler
init callbacks for setting the parameter values 
";

%feature("docstring")  DepthProbeSimulation::beam "Beam & DepthProbeSimulation::beam()
DepthProbeSimulation::beam";

%feature("docstring")  DepthProbeSimulation::beam "const Beam & DepthProbeSimulation::beam() const
DepthProbeSimulation::beam";

%feature("docstring")  DepthProbeSimulation::createCoordSystem "ICoordSystem * DepthProbeSimulation::createCoordSystem() const override
DepthProbeSimulation::createCoordSystem";


// File: classDWBAComputation.xml
%feature("docstring") DWBAComputation "

Provides function that performs a single-threaded DWBA computation for a range of DiffuseElements.

Handles progress counter and interrupts, runs loop over DiffuseElements, delegates all further work to DWBATerm.

Controlled by the multi-threading machinery in ISimulation::runSingleSimulation().

C++ includes: DWBAComputation.h
";

%feature("docstring")  DWBAComputation::DWBAComputation "DWBAComputation::DWBAComputation(const ReSample &re_sample, const SimulationOptions &options, ProgressHandler &progress, std::vector< DiffuseElement >::iterator begin_it, std::vector< DiffuseElement >::iterator end_it)
DWBAComputation::DWBAComputation";

%feature("docstring")  DWBAComputation::~DWBAComputation "DWBAComputation::~DWBAComputation() override
DWBAComputation::~DWBAComputation";


// File: classFitObjective.xml
%feature("docstring") FitObjective "

Holds vector of  SimDataPairs (experimental data and simulation results) for use in fitting. Thereby supports simultaneous fitting of several data sets and model functions, as demonstrated in example fit52/multiple_datasets.

C++ includes: FitObjective.h
";

%feature("docstring")  FitObjective::FitObjective "FitObjective::FitObjective()
FitObjective::FitObjective";

%feature("docstring")  FitObjective::~FitObjective "FitObjective::~FitObjective()
FitObjective::~FitObjective";

%feature("docstring")  FitObjective::execAddSimulationAndData "void FitObjective::execAddSimulationAndData(const simulation_builder_t &builder, const Datafield &data, std::unique_ptr< Datafield > &&stdv, double weight=1.0)
FitObjective::execAddSimulationAndData
Constructs simulation/data pair for later fit.

Parameters:
-----------

builder: 
simulation builder capable of producing simulations

data: 
experimental data array

stdv: 
data uncertainties array

weight: 
weight of dataset in metric calculations

Should be private, but is used in several tests. 
";

%feature("docstring")  FitObjective::addSimulationAndData "void FitObjective::addSimulationAndData(const PyBuilderCallback &callback, const std::vector< std::vector< double > > &data, double weight=1.0)
FitObjective::addSimulationAndData
Constructs simulation/data pair for later fit.

Parameters:
-----------

callback: 
simulation builder capable of producing simulations

data: 
experimental data array

weight: 
weight of dataset in metric calculations 
";

%feature("docstring")  FitObjective::addSimulationAndData "void FitObjective::addSimulationAndData(const PyBuilderCallback &callback, const std::vector< double > &data, double weight=1.0)
FitObjective::addSimulationAndData";

%feature("docstring")  FitObjective::addSimulationAndData "void FitObjective::addSimulationAndData(const PyBuilderCallback &callback, const std::vector< std::vector< double > > &data, const std::vector< std::vector< double > > &stdv, double weight=1.0)
FitObjective::addSimulationAndData
Constructs simulation/data pair for later fit.

Parameters:
-----------

callback: 
simulation builder capable of producing simulations

data: 
experimental data array

stdv: 
data uncertainties array

weight: 
weight of dataset in metric calculations 
";

%feature("docstring")  FitObjective::addSimulationAndData "void FitObjective::addSimulationAndData(const PyBuilderCallback &callback, const std::vector< double > &data, const std::vector< double > &stdv, double weight=1.0)
FitObjective::addSimulationAndData";

%feature("docstring")  FitObjective::evaluate "double FitObjective::evaluate(const mumufit::Parameters &params)
FitObjective::evaluate";

%feature("docstring")  FitObjective::evaluate_residuals "std::vector< double > FitObjective::evaluate_residuals(const mumufit::Parameters &params)
FitObjective::evaluate_residuals";

%feature("docstring")  FitObjective::simulationResult "SimulationResult FitObjective::simulationResult(size_t i_item=0) const
FitObjective::simulationResult
Returns simulation result in the form of SimulationResult. 
";

%feature("docstring")  FitObjective::experimentalData "SimulationResult FitObjective::experimentalData(size_t i_item=0) const
FitObjective::experimentalData
Returns experimental data in the form of SimulationResult. 
";

%feature("docstring")  FitObjective::uncertaintyData "SimulationResult FitObjective::uncertaintyData(size_t i_item=0) const
FitObjective::uncertaintyData
Returns experimental data uncertainties in the form of SimulationResult. 
";

%feature("docstring")  FitObjective::relativeDifference "SimulationResult FitObjective::relativeDifference(size_t i_item=0) const
FitObjective::relativeDifference
Returns relative difference between simulation and experimental data in the form of SimulationResult. 
";

%feature("docstring")  FitObjective::absoluteDifference "SimulationResult FitObjective::absoluteDifference(size_t i_item=0) const
FitObjective::absoluteDifference
Returns absolute value of difference between simulation and experimental data in the form of SimulationResult. 
";

%feature("docstring")  FitObjective::experimental_array "std::vector< double > FitObjective::experimental_array() const
FitObjective::experimental_array
Returns one-dimensional array representing merged experimental data. The area outside of the region of interest is not included, masked data is nullified. 
";

%feature("docstring")  FitObjective::simulation_array "std::vector< double > FitObjective::simulation_array() const
FitObjective::simulation_array
Returns one-dimensional array representing merged simulated intensities data. The area outside of the region of interest is not included, masked data is nullified. 
";

%feature("docstring")  FitObjective::uncertainties "std::vector< double > FitObjective::uncertainties() const
FitObjective::uncertainties
Returns one-dimensional array representing merged data uncertainties. The area outside of the region of interest is not included, masked data is nullified. 
";

%feature("docstring")  FitObjective::weights_array "std::vector< double > FitObjective::weights_array() const
FitObjective::weights_array
Returns one-dimensional array representing merged user weights. The area outside of the region of interest is not included, masked data is nullified. 
";

%feature("docstring")  FitObjective::initPrint "void FitObjective::initPrint(int every_nth)
FitObjective::initPrint
Initializes printing to standard output on every_nth fit iteration. 
";

%feature("docstring")  FitObjective::initPlot "void FitObjective::initPlot(int every_nth, PyObserverCallback &callback)
FitObjective::initPlot
Initializes observer callback to be called on every_nth fit iteration. 
";

%feature("docstring")  FitObjective::iterationInfo "IterationInfo FitObjective::iterationInfo() const
FitObjective::iterationInfo";

%feature("docstring")  FitObjective::minimizerResult "mumufit::MinimizerResult FitObjective::minimizerResult() const
FitObjective::minimizerResult";

%feature("docstring")  FitObjective::finalize "void FitObjective::finalize(const mumufit::MinimizerResult &result)
FitObjective::finalize
Should be explicitly called on last iteration to notify all observers. 
";

%feature("docstring")  FitObjective::fitObjectCount "unsigned FitObjective::fitObjectCount() const
FitObjective::fitObjectCount";

%feature("docstring")  FitObjective::execSimulations "void FitObjective::execSimulations(const mumufit::Parameters &params)
FitObjective::execSimulations";

%feature("docstring")  FitObjective::setChiSquaredModule "void FitObjective::setChiSquaredModule(const IChiSquaredModule &module)
FitObjective::setChiSquaredModule";

%feature("docstring")  FitObjective::setObjectiveMetric "void FitObjective::setObjectiveMetric(const std::string &metric)
FitObjective::setObjectiveMetric";

%feature("docstring")  FitObjective::setObjectiveMetric "void FitObjective::setObjectiveMetric(const std::string &metric, const std::string &norm)
FitObjective::setObjectiveMetric
Sets objective metric to the  FitObjective.

Parameters:
-----------

metric: 
metric name

norm: 
metric norm name (defaults to L2-norm) 
";

%feature("docstring")  FitObjective::containsUncertainties "bool FitObjective::containsUncertainties(size_t i_item) const
FitObjective::containsUncertainties
Returns true if the specified DataPair element contains uncertainties. 
";

%feature("docstring")  FitObjective::allPairsHaveUncertainties "bool FitObjective::allPairsHaveUncertainties() const
FitObjective::allPairsHaveUncertainties
Returns true if all the data pairs in  FitObjective instance contain uncertainties. 
";

%feature("docstring")  FitObjective::dataPair "const SimDataPair & FitObjective::dataPair(size_t i_item=0) const
FitObjective::dataPair
Returns a reference to i-th  SimDataPair. 
";

%feature("docstring")  FitObjective::initPlot "void FitObjective::initPlot(int every_nth, fit_observer_t &&observer)
FitObjective::initPlot";

%feature("docstring")  FitObjective::isCompleted "bool FitObjective::isCompleted() const
FitObjective::isCompleted";

%feature("docstring")  FitObjective::interruptFitting "void FitObjective::interruptFitting()
FitObjective::interruptFitting";

%feature("docstring")  FitObjective::isInterrupted "bool FitObjective::isInterrupted() const
FitObjective::isInterrupted";

%feature("docstring")  FitObjective::isFirstIteration "bool FitObjective::isFirstIteration() const
FitObjective::isFirstIteration";

%feature("docstring")  FitObjective::setObjectiveMetric "void FitObjective::setObjectiveMetric(std::unique_ptr< ObjectiveMetric > metric)
FitObjective::setObjectiveMetric";


// File: classFitObserver.xml
%feature("docstring") FitObserver "

Contains collection of observers and call them at specified intervals. Each observer will be called at first iteration and every-nth iterations.

C++ includes: FitObserver.h
";

%feature("docstring")  FitObserver::FitObserver "FitObserver< T >::FitObserver()
FitObserver::FitObserver";

%feature("docstring")  FitObserver::addObserver "void FitObserver< T >::addObserver(int every_nth, observer_t &&observer)
FitObserver::addObserver
Adds observer to the list.

Parameters:
-----------

every_nth: 
An observer function will be called every_nth iterations.

observer: 
Observer function to be called. 
";

%feature("docstring")  FitObserver::notify "void FitObserver< T >::notify(const T &data)
FitObserver::notify
Notifies all observers at their personally specified intervals.

Parameters:
-----------

data: 
The data which will be passed to the observer. 
";

%feature("docstring")  FitObserver::notify_all "void FitObserver< T >::notify_all(const T &data)
FitObserver::notify_all";


// File: classFitPrintService.xml
%feature("docstring") FitPrintService "

Prints fit statistics to standard output during minimizer iterations.

C++ includes: FitPrintService.h
";

%feature("docstring")  FitPrintService::FitPrintService "FitPrintService::FitPrintService()
FitPrintService::FitPrintService";

%feature("docstring")  FitPrintService::print "void FitPrintService::print(const FitObjective &objective)
FitPrintService::print";


// File: classFitStatus.xml
%feature("docstring") FitStatus "

Contains status of the fitting (running, interupted etc) and all intermediate information which has to be collected during the fit. Owned by  FitObjective.

C++ includes: FitStatus.h
";

%feature("docstring")  FitStatus::FitStatus "FitStatus::FitStatus(const FitObjective *fit_objective)
FitStatus::FitStatus";

%feature("docstring")  FitStatus::~FitStatus "FitStatus::~FitStatus()
FitStatus::~FitStatus";

%feature("docstring")  FitStatus::setInterrupted "void FitStatus::setInterrupted()
FitStatus::setInterrupted";

%feature("docstring")  FitStatus::isInterrupted "bool FitStatus::isInterrupted() const
FitStatus::isInterrupted";

%feature("docstring")  FitStatus::isCompleted "bool FitStatus::isCompleted() const
FitStatus::isCompleted";

%feature("docstring")  FitStatus::update "void FitStatus::update(const mumufit::Parameters &params, double chi2)
FitStatus::update";

%feature("docstring")  FitStatus::initPrint "void FitStatus::initPrint(int every_nth)
FitStatus::initPrint";

%feature("docstring")  FitStatus::addObserver "void FitStatus::addObserver(int every_nth, fit_observer_t &&)
FitStatus::addObserver";

%feature("docstring")  FitStatus::iterationInfo "IterationInfo FitStatus::iterationInfo() const
FitStatus::iterationInfo";

%feature("docstring")  FitStatus::minimizerResult "mumufit::MinimizerResult FitStatus::minimizerResult() const
FitStatus::minimizerResult";

%feature("docstring")  FitStatus::finalize "void FitStatus::finalize(const mumufit::MinimizerResult &result)
FitStatus::finalize
Should be explicitly called on last iteration to notify all observers. 
";


// File: classGISASSpecularContribution.xml
%feature("docstring") GISASSpecularContribution "

Computes the specular signal in the bin where q_parallel = 0. Used by  DWBAComputation.

C++ includes: GISASSpecularContribution.h
";

%feature("docstring")  GISASSpecularContribution::GISASSpecularContribution "GISASSpecularContribution::GISASSpecularContribution()=default
GISASSpecularContribution::GISASSpecularContribution";

%feature("docstring")  GISASSpecularContribution::compute "void GISASSpecularContribution::compute(DiffuseElement &ele) const
GISASSpecularContribution::compute";


// File: classIBackground.xml
%feature("docstring") IBackground "

Abstract base class for background noise, to be added to simulated scattering.

Base class of  ConstantBackground,  PoissonBackground.

C++ includes: IBackground.h
";

%feature("docstring")  IBackground::IBackground "IBackground::IBackground(const std::vector< double > &PValues)
IBackground::IBackground";

%feature("docstring")  IBackground::~IBackground "IBackground::~IBackground() override
IBackground::~IBackground";

%feature("docstring")  IBackground::clone "IBackground * IBackground::clone() const override=0
IBackground::clone";

%feature("docstring")  IBackground::addBackground "virtual double IBackground::addBackground(double element) const =0
IBackground::addBackground";


// File: classIChiSquaredModule.xml
%feature("docstring") IChiSquaredModule "

Interface residual calculations.

C++ includes: IChiSquaredModule.h
";

%feature("docstring")  IChiSquaredModule::IChiSquaredModule "IChiSquaredModule::IChiSquaredModule()
IChiSquaredModule::IChiSquaredModule";

%feature("docstring")  IChiSquaredModule::~IChiSquaredModule "IChiSquaredModule::~IChiSquaredModule() override
IChiSquaredModule::~IChiSquaredModule";

%feature("docstring")  IChiSquaredModule::clone "IChiSquaredModule * IChiSquaredModule::clone() const override=0
IChiSquaredModule::clone
clone method 
";

%feature("docstring")  IChiSquaredModule::varianceFunction "const IVarianceFunction * IChiSquaredModule::varianceFunction() const
IChiSquaredModule::varianceFunction
Returns squared function. 
";

%feature("docstring")  IChiSquaredModule::setVarianceFunction "void IChiSquaredModule::setVarianceFunction(const IVarianceFunction &variance_function)
IChiSquaredModule::setVarianceFunction
Sets squared function. 
";

%feature("docstring")  IChiSquaredModule::getIntensityFunction "const IIntensityFunction * IChiSquaredModule::getIntensityFunction() const
IChiSquaredModule::getIntensityFunction
Returns data rescaler. 
";

%feature("docstring")  IChiSquaredModule::setIntensityFunction "void IChiSquaredModule::setIntensityFunction(const IIntensityFunction &intensity_function)
IChiSquaredModule::setIntensityFunction
Sets data rescaler. 
";

%feature("docstring")  IChiSquaredModule::residual "virtual double IChiSquaredModule::residual(double a, double b, double weight)=0
IChiSquaredModule::residual";


// File: classIComputation.xml
%feature("docstring") IComputation "

Interface for a single-threaded computation with given range of DiffuseElements and ProgressHandler.

Controlled by the multi-threading machinery in ISimulation::runSingleSimulation().

C++ includes: IComputation.h
";

%feature("docstring")  IComputation::IComputation "IComputation::IComputation(const ReSample &re_sample, const SimulationOptions &options, ProgressHandler &progress)
IComputation::IComputation";

%feature("docstring")  IComputation::~IComputation "IComputation::~IComputation()
IComputation::~IComputation";

%feature("docstring")  IComputation::compute "void IComputation::compute()
IComputation::compute
Calls runProtected(), catches exceptions, sets m_status. 
";

%feature("docstring")  IComputation::isCompleted "bool IComputation::isCompleted() const
IComputation::isCompleted";

%feature("docstring")  IComputation::errorMessage "std::string IComputation::errorMessage() const
IComputation::errorMessage";


// File: classIIntensityFunction.xml
%feature("docstring") IIntensityFunction "

Interface for applying arbitrary function to the measured intensity.

C++ includes: IIntensityFunction.h
";

%feature("docstring")  IIntensityFunction::~IIntensityFunction "IIntensityFunction::~IIntensityFunction()
IIntensityFunction::~IIntensityFunction";

%feature("docstring")  IIntensityFunction::clone "virtual IIntensityFunction * IIntensityFunction::clone() const =0
IIntensityFunction::clone";

%feature("docstring")  IIntensityFunction::evaluate "virtual double IIntensityFunction::evaluate(double value) const =0
IIntensityFunction::evaluate";


// File: classIMetricWrapper.xml
%feature("docstring") IMetricWrapper "";

%feature("docstring")  IMetricWrapper::~IMetricWrapper "virtual IMetricWrapper::~IMetricWrapper()=default
IMetricWrapper::~IMetricWrapper";

%feature("docstring")  IMetricWrapper::compute "virtual double IMetricWrapper::compute(const std::vector< SimDataPair > &fit_objects, size_t n_pars) const =0
IMetricWrapper::compute";


// File: classIntensityFunctionLog.xml
%feature("docstring") IntensityFunctionLog "

Algorithm for applying log function to the measured intensity.

C++ includes: IIntensityFunction.h
";

%feature("docstring")  IntensityFunctionLog::clone "IntensityFunctionLog * IntensityFunctionLog::clone() const override
IntensityFunctionLog::clone";

%feature("docstring")  IntensityFunctionLog::evaluate "double IntensityFunctionLog::evaluate(double value) const override
IntensityFunctionLog::evaluate";


// File: classIntensityFunctionSqrt.xml
%feature("docstring") IntensityFunctionSqrt "

Algorithm for applying sqrt function to the measured intensity.

C++ includes: IIntensityFunction.h
";

%feature("docstring")  IntensityFunctionSqrt::clone "IntensityFunctionSqrt * IntensityFunctionSqrt::clone() const override
IntensityFunctionSqrt::clone";

%feature("docstring")  IntensityFunctionSqrt::evaluate "double IntensityFunctionSqrt::evaluate(double value) const override
IntensityFunctionSqrt::evaluate";


// File: classISimulation.xml
%feature("docstring") ISimulation "

Abstract base class, holds the infrastructure to run a simulation.

Base class of  SpecularSimulation,  ISimulation2D and  DepthProbeSimulation.

Holds an instrument and sample model. Provides the common infrastructure to run a simulation: multithreading, batch processing, averaging over parameter distributions, etc.

Simulations are run, and results returned, by the function  ISimulation::simulate().

C++ includes: ISimulation.h
";

%feature("docstring")  ISimulation::ISimulation "ISimulation::ISimulation(const MultiLayer &sample)
ISimulation::ISimulation";

%feature("docstring")  ISimulation::~ISimulation "ISimulation::~ISimulation() override
ISimulation::~ISimulation";

%feature("docstring")  ISimulation::ISimulation "ISimulation::ISimulation(const ISimulation &)=delete
ISimulation::ISimulation";

%feature("docstring")  ISimulation::ISimulation "ISimulation::ISimulation(ISimulation &&)=default
ISimulation::ISimulation";

%feature("docstring")  ISimulation::simulate "SimulationResult ISimulation::simulate()
ISimulation::simulate
Run a simulation, and return the result.

Runs simulation with possible averaging over parameter distributions; returns result. 
";

%feature("docstring")  ISimulation::setBackground "void ISimulation::setBackground(const IBackground &bg)
ISimulation::setBackground";

%feature("docstring")  ISimulation::addParameterDistribution "void ISimulation::addParameterDistribution(ParameterDistribution::WhichParameter whichParameter, const IDistribution1D &distribution, size_t nbr_samples, double sigma_factor=0.0, const RealLimits &limits=RealLimits())
ISimulation::addParameterDistribution";

%feature("docstring")  ISimulation::addParameterDistribution "void ISimulation::addParameterDistribution(const ParameterDistribution &par_distr)
ISimulation::addParameterDistribution";

%feature("docstring")  ISimulation::options "const SimulationOptions & ISimulation::options() const
ISimulation::options";

%feature("docstring")  ISimulation::options "SimulationOptions & ISimulation::options()
ISimulation::options";

%feature("docstring")  ISimulation::setTerminalProgressMonitor "void ISimulation::setTerminalProgressMonitor()
ISimulation::setTerminalProgressMonitor
Initializes a progress monitor that prints to stdout. 
";

%feature("docstring")  ISimulation::force_polarized "virtual bool ISimulation::force_polarized() const =0
ISimulation::force_polarized
Force polarized computation even in absence of sample magnetization or external fields. 
";

%feature("docstring")  ISimulation::subscribe "void ISimulation::subscribe(const std::function< bool(size_t)> &inform)
ISimulation::subscribe";

%feature("docstring")  ISimulation::unitOfParameter "std::string ISimulation::unitOfParameter(ParameterDistribution::WhichParameter which) const
ISimulation::unitOfParameter";

%feature("docstring")  ISimulation::sample "const MultiLayer * ISimulation::sample() const
ISimulation::sample";

%feature("docstring")  ISimulation::background "const IBackground * ISimulation::background() const
ISimulation::background";

%feature("docstring")  ISimulation::getDistributions "const std::vector< ParameterDistribution > & ISimulation::getDistributions() const
ISimulation::getDistributions";

%feature("docstring")  ISimulation::nodeChildren "std::vector< const INode * > ISimulation::nodeChildren() const override
ISimulation::nodeChildren";

%feature("docstring")  ISimulation::createCoordSystem "virtual ICoordSystem * ISimulation::createCoordSystem() const =0
ISimulation::createCoordSystem";


// File: classISimulation2D.xml
%feature("docstring") ISimulation2D "

Abstract base class of simulations that generate 2D patterns.

Base class of  OffspecSimulation and  ScatteringSimulation.

Holds the common implementations for simulations with a 2D detector.

C++ includes: ISimulation2D.h
";

%feature("docstring")  ISimulation2D::ISimulation2D "ISimulation2D::ISimulation2D(const Beam &beam, const MultiLayer &sample, const IDetector &detector)
ISimulation2D::ISimulation2D";

%feature("docstring")  ISimulation2D::ISimulation2D "ISimulation2D::ISimulation2D(const MultiLayer &sample)
ISimulation2D::ISimulation2D";

%feature("docstring")  ISimulation2D::~ISimulation2D "ISimulation2D::~ISimulation2D() override
ISimulation2D::~ISimulation2D";

%feature("docstring")  ISimulation2D::nodeChildren "std::vector< const INode * > ISimulation2D::nodeChildren() const override
ISimulation2D::nodeChildren";

%feature("docstring")  ISimulation2D::force_polarized "bool ISimulation2D::force_polarized() const override
ISimulation2D::force_polarized
Force polarized computation even in absence of sample magnetization or external fields. 
";

%feature("docstring")  ISimulation2D::addMask "void ISimulation2D::addMask(const IShape2D &shape, bool mask_value=true)
ISimulation2D::addMask
Adds mask of given shape to the stack of detector masks. The mask value 'true' means that the channel will be excluded from the simulation. The mask which is added last has priority.

Parameters:
-----------

shape: 
The shape of mask (Rectangle, Polygon, Line, Ellipse)

mask_value: 
The value of mask 
";

%feature("docstring")  ISimulation2D::maskAll "void ISimulation2D::maskAll()
ISimulation2D::maskAll
Put the mask for all detector channels (i.e. exclude whole detector from the analysis) 
";

%feature("docstring")  ISimulation2D::setRegionOfInterest "void ISimulation2D::setRegionOfInterest(double xlow, double ylow, double xup, double yup)
ISimulation2D::setRegionOfInterest
Sets rectangular region of interest with lower left and upper right corners defined. 
";

%feature("docstring")  ISimulation2D::beam "Beam & ISimulation2D::beam()
ISimulation2D::beam";

%feature("docstring")  ISimulation2D::detector "IDetector & ISimulation2D::detector()
ISimulation2D::detector";

%feature("docstring")  ISimulation2D::beam "const Beam & ISimulation2D::beam() const
ISimulation2D::beam";

%feature("docstring")  ISimulation2D::detector "const IDetector & ISimulation2D::detector() const
ISimulation2D::detector";

%feature("docstring")  ISimulation2D::getDetector "const IDetector * ISimulation2D::getDetector() const
ISimulation2D::getDetector";


// File: classISpecularScan.xml
%feature("docstring") ISpecularScan "

Abstract base class for all types of specular scans.

C++ includes: ISpecularScan.h
";

%feature("docstring")  ISpecularScan::clone "ISpecularScan * ISpecularScan::clone() const override=0
ISpecularScan::clone";

%feature("docstring")  ISpecularScan::~ISpecularScan "ISpecularScan::~ISpecularScan() override
ISpecularScan::~ISpecularScan";

%feature("docstring")  ISpecularScan::setPolarization "void ISpecularScan::setPolarization(R3 bloch_vector)
ISpecularScan::setPolarization
Sets the polarization density matrix according to the given Bloch vector. 
";

%feature("docstring")  ISpecularScan::setAnalyzer "void ISpecularScan::setAnalyzer(R3 direction, double efficiency, double total_transmission)
ISpecularScan::setAnalyzer
Sets the polarization analyzer characteristics of the detector. 
";

%feature("docstring")  ISpecularScan::analyzer "const PolFilter * ISpecularScan::analyzer() const
ISpecularScan::analyzer";

%feature("docstring")  ISpecularScan::wavelength "virtual double ISpecularScan::wavelength() const =0
ISpecularScan::wavelength";

%feature("docstring")  ISpecularScan::polMatrices "PolMatrices ISpecularScan::polMatrices() const
ISpecularScan::polMatrices";

%feature("docstring")  ISpecularScan::generateElements "virtual std::vector< SpecularElement > ISpecularScan::generateElements() const =0
ISpecularScan::generateElements
Generates simulation elements for specular simulations. 
";

%feature("docstring")  ISpecularScan::coordinateAxis "virtual const IAxis * ISpecularScan::coordinateAxis() const =0
ISpecularScan::coordinateAxis
Returns coordinate axis assigned to the data holder. 
";

%feature("docstring")  ISpecularScan::footprintFactor "virtual const IFootprintFactor * ISpecularScan::footprintFactor() const =0
ISpecularScan::footprintFactor
Returns IFootprintFactor object pointer. 
";

%feature("docstring")  ISpecularScan::footprint "virtual std::vector< double > ISpecularScan::footprint(size_t i, size_t n_elements) const =0
ISpecularScan::footprint
Returns footprint correction factor for a range of simulation elements of size  n_elements and starting from element with index  i. 
";

%feature("docstring")  ISpecularScan::numberOfElements "virtual size_t ISpecularScan::numberOfElements() const =0
ISpecularScan::numberOfElements
Returns the number of simulation elements. 
";

%feature("docstring")  ISpecularScan::createCoordSystem "virtual CoordSystem1D * ISpecularScan::createCoordSystem() const =0
ISpecularScan::createCoordSystem";

%feature("docstring")  ISpecularScan::createIntensities "virtual std::vector< double > ISpecularScan::createIntensities(const std::vector< SpecularElement > &eles) const =0
ISpecularScan::createIntensities
Returns intensity vector corresponding to convolution of given simulation elements. 
";

%feature("docstring")  ISpecularScan::polarized "bool ISpecularScan::polarized() const
ISpecularScan::polarized";


// File: classIterationInfo.xml
%feature("docstring") IterationInfo "

Stores fit iteration info to track fit flow from various observers. Used in context of  FitObjective.

C++ includes: IterationInfo.h
";

%feature("docstring")  IterationInfo::IterationInfo "IterationInfo::IterationInfo()
IterationInfo::IterationInfo";

%feature("docstring")  IterationInfo::update "void IterationInfo::update(const mumufit::Parameters &params, double chi2)
IterationInfo::update";

%feature("docstring")  IterationInfo::iterationCount "unsigned IterationInfo::iterationCount() const
IterationInfo::iterationCount
Returns current number of minimizer iterations. 
";

%feature("docstring")  IterationInfo::chi2 "double IterationInfo::chi2() const
IterationInfo::chi2";

%feature("docstring")  IterationInfo::parameters "mumufit::Parameters IterationInfo::parameters() const
IterationInfo::parameters";

%feature("docstring")  IterationInfo::parameterMap "std::map< std::string, double > IterationInfo::parameterMap() const
IterationInfo::parameterMap
Returns map of fit parameter names and its current values. 
";


// File: classIVarianceFunction.xml
%feature("docstring") IVarianceFunction "

Variance function interface.

C++ includes: VarianceFunctions.h
";

%feature("docstring")  IVarianceFunction::IVarianceFunction "IVarianceFunction::IVarianceFunction()=default
IVarianceFunction::IVarianceFunction";

%feature("docstring")  IVarianceFunction::~IVarianceFunction "virtual IVarianceFunction::~IVarianceFunction()=default
IVarianceFunction::~IVarianceFunction";

%feature("docstring")  IVarianceFunction::IVarianceFunction "IVarianceFunction::IVarianceFunction(const IVarianceFunction &)=delete
IVarianceFunction::IVarianceFunction";

%feature("docstring")  IVarianceFunction::clone "virtual IVarianceFunction * IVarianceFunction::clone() const =0
IVarianceFunction::clone";

%feature("docstring")  IVarianceFunction::variance "virtual double IVarianceFunction::variance(double real_value, double simulated_value) const =0
IVarianceFunction::variance";


// File: classLogMetric.xml
%feature("docstring") LogMetric "

Implementation of the standard  $ \\\\chi^2 $ metric with intensity  $I$ and experimental data  $D$ being replaced by  $ \\\\log_{10} I $ and  $\\\\log_{10} D$ accordingly. With default L2 norm corresponds to the formula  \\\\[\\\\chi^2 = \\\\sum \\\\frac{(\\\\log_{10} I - log_{10} D)^2 D^2 \\\\ln^2{10}}{\\\\delta_D^2}\\\\]

C++ includes: ObjectiveMetric.h
";

%feature("docstring")  LogMetric::LogMetric "LogMetric::LogMetric()
LogMetric::LogMetric";

%feature("docstring")  LogMetric::clone "LogMetric * LogMetric::clone() const override
LogMetric::clone";

%feature("docstring")  LogMetric::computeFromArrays "double LogMetric::computeFromArrays(std::vector< double > sim_data, std::vector< double > exp_data, std::vector< double > exp_stdv, std::vector< double > weight_factors) const override
LogMetric::computeFromArrays
Computes metric value from data arrays. Negative values in exp_data are ignored as well as non-positive weight_factors and uncertainties. All arrays involved in the computation must be of the same size.

Parameters:
-----------

sim_data: 
array with simulated intensities.

exp_data: 
array with intensity values obtained from an experiment.

exp_stdv: 
array with experimental data uncertainties.

weight_factors: 
user-defined weighting factors. Used linearly, no matter which norm is chosen. 
";

%feature("docstring")  LogMetric::computeFromArrays "double LogMetric::computeFromArrays(std::vector< double > sim_data, std::vector< double > exp_data, std::vector< double > weight_factors) const override
LogMetric::computeFromArrays
Computes metric value from data arrays. Negative values in exp_data are ignored as well as non-positive weight_factors. All arrays involved in the computation must be of the same size.

Parameters:
-----------

sim_data: 
array with simulated intensities.

exp_data: 
array with intensity values obtained from an experiment.

weight_factors: 
user-defined weighting factors. Used linearly, no matter which norm is chosen. 
";


// File: classMaterialKeyHandler.xml
%feature("docstring") MaterialKeyHandler "

Stores Material instances, associates them with given tag, and provides unique keys.

C++ includes: MaterialKeyHandler.h
";

%feature("docstring")  MaterialKeyHandler::insertMaterial "void MaterialKeyHandler::insertMaterial(const Material *mat)
MaterialKeyHandler::insertMaterial";

%feature("docstring")  MaterialKeyHandler::materialMap "const std::map< const std::string, const Material * > & MaterialKeyHandler::materialMap() const
MaterialKeyHandler::materialMap";

%feature("docstring")  MaterialKeyHandler::mat2key "const std::string & MaterialKeyHandler::mat2key(const Material *mat) const
MaterialKeyHandler::mat2key";


// File: classmeanRelativeDifferenceMetric.xml
%feature("docstring") meanRelativeDifferenceMetric "

Implementation of relative difference metric. With default L2 norm and weighting off corresponds to the formula  \\\\[Result = \\\\sum \\\\frac{(I - D)^2}{(I + D)^2}\\\\] where  $I$ is the simulated intensity,  $D$ - experimental data. If weighting is on, falls back to the standard  $\\\\chi^2$ metric.

C++ includes: ObjectiveMetric.h
";

%feature("docstring")  meanRelativeDifferenceMetric::meanRelativeDifferenceMetric "meanRelativeDifferenceMetric::meanRelativeDifferenceMetric()
meanRelativeDifferenceMetric::meanRelativeDifferenceMetric";

%feature("docstring")  meanRelativeDifferenceMetric::clone "meanRelativeDifferenceMetric * meanRelativeDifferenceMetric::clone() const override
meanRelativeDifferenceMetric::clone";

%feature("docstring")  meanRelativeDifferenceMetric::computeFromArrays "double meanRelativeDifferenceMetric::computeFromArrays(std::vector< double > sim_data, std::vector< double > exp_data, std::vector< double > weight_factors) const override
meanRelativeDifferenceMetric::computeFromArrays
Computes metric value from data arrays. Negative values in exp_data are ignored as well as non-positive weight_factors. All arrays involved in the computation must be of the same size.

Parameters:
-----------

sim_data: 
array with simulated intensities.

exp_data: 
array with intensity values obtained from an experiment.

weight_factors: 
user-defined weighting factors. Used linearly, no matter which norm is chosen. 
";

%feature("docstring")  meanRelativeDifferenceMetric::computeFromArrays "double Chi2Metric::computeFromArrays(std::vector< double > sim_data, std::vector< double > exp_data, std::vector< double > exp_stdv, std::vector< double > weight_factors) const override
meanRelativeDifferenceMetric::computeFromArrays
Computes metric value from data arrays. Negative values in exp_data are ignored as well as non-positive weight_factors and uncertainties. All arrays involved in the computation must be of the same size.

Parameters:
-----------

sim_data: 
array with simulated intensities.

exp_data: 
array with intensity values obtained from an experiment.

exp_stdv: 
array with experimental data uncertainties.

weight_factors: 
user-defined weighting factors. Used linearly, no matter which norm is chosen. 
";

%feature("docstring")  meanRelativeDifferenceMetric::computeFromArrays "double Chi2Metric::computeFromArrays(std::vector< double > sim_data, std::vector< double > exp_data, std::vector< double > weight_factors) const override
meanRelativeDifferenceMetric::computeFromArrays
Computes metric value from data arrays. Negative values in exp_data are ignored as well as non-positive weight_factors. All arrays involved in the computation must be of the same size.

Parameters:
-----------

sim_data: 
array with simulated intensities.

exp_data: 
array with intensity values obtained from an experiment.

weight_factors: 
user-defined weighting factors. Used linearly, no matter which norm is chosen. 
";


// File: classObjectiveMetric.xml
%feature("docstring") ObjectiveMetric "

Base class for metric implementations.

C++ includes: ObjectiveMetric.h
";

%feature("docstring")  ObjectiveMetric::ObjectiveMetric "ObjectiveMetric::ObjectiveMetric(std::function< double(double)> norm)
ObjectiveMetric::ObjectiveMetric";

%feature("docstring")  ObjectiveMetric::clone "ObjectiveMetric * ObjectiveMetric::clone() const override=0
ObjectiveMetric::clone";

%feature("docstring")  ObjectiveMetric::compute "double ObjectiveMetric::compute(const SimDataPair &data_pair, bool use_weights) const
ObjectiveMetric::compute
Computes metric value from  SimDataPair object. Calls computeFromArrays internally.

Parameters:
-----------

data_pair: 
 SimDataPair object. Can optionally contain data uncertainties

use_weights: 
boolean, defines if data uncertainties should be taken into account 
";

%feature("docstring")  ObjectiveMetric::computeFromArrays "virtual double ObjectiveMetric::computeFromArrays(std::vector< double > sim_data, std::vector< double > exp_data, std::vector< double > exp_stdv, std::vector< double > weight_factors) const =0
ObjectiveMetric::computeFromArrays
Computes metric value from data arrays. Negative values in exp_data are ignored as well as non-positive weight_factors and uncertainties. All arrays involved in the computation must be of the same size.

Parameters:
-----------

sim_data: 
array with simulated intensities.

exp_data: 
array with intensity values obtained from an experiment.

exp_stdv: 
array with experimental data uncertainties.

weight_factors: 
user-defined weighting factors. Used linearly, no matter which norm is chosen. 
";

%feature("docstring")  ObjectiveMetric::computeFromArrays "virtual double ObjectiveMetric::computeFromArrays(std::vector< double > sim_data, std::vector< double > exp_data, std::vector< double > weight_factors) const =0
ObjectiveMetric::computeFromArrays
Computes metric value from data arrays. Negative values in exp_data are ignored as well as non-positive weight_factors. All arrays involved in the computation must be of the same size.

Parameters:
-----------

sim_data: 
array with simulated intensities.

exp_data: 
array with intensity values obtained from an experiment.

weight_factors: 
user-defined weighting factors. Used linearly, no matter which norm is chosen. 
";

%feature("docstring")  ObjectiveMetric::setNorm "void ObjectiveMetric::setNorm(std::function< double(double)> norm)
ObjectiveMetric::setNorm";

%feature("docstring")  ObjectiveMetric::norm "auto ObjectiveMetric::norm() const
ObjectiveMetric::norm
Returns a copy of the normalization function used. 
";


// File: classObjectiveMetricWrapper.xml
%feature("docstring") ObjectiveMetricWrapper "";

%feature("docstring")  ObjectiveMetricWrapper::ObjectiveMetricWrapper "ObjectiveMetricWrapper::ObjectiveMetricWrapper(std::unique_ptr< ObjectiveMetric > module)
ObjectiveMetricWrapper::ObjectiveMetricWrapper";

%feature("docstring")  ObjectiveMetricWrapper::compute "double ObjectiveMetricWrapper::compute(const std::vector< SimDataPair > &fit_objects, size_t n_pars) const override
ObjectiveMetricWrapper::compute";


// File: classFitObserver_1_1ObserverData.xml


// File: classOffspecSimulation.xml
%feature("docstring") OffspecSimulation "

Off-specular scattering simulation.

Holds an instrument and sample model. Computes reflected and scattered intensity as function of incident and final glancing angle.

C++ includes: OffspecSimulation.h
";

%feature("docstring")  OffspecSimulation::OffspecSimulation "OffspecSimulation::OffspecSimulation(const Beam &beam, const MultiLayer &sample, const IDetector &detector)
OffspecSimulation::OffspecSimulation";

%feature("docstring")  OffspecSimulation::OffspecSimulation "OffspecSimulation::OffspecSimulation(const MultiLayer &sample)
OffspecSimulation::OffspecSimulation";

%feature("docstring")  OffspecSimulation::~OffspecSimulation "OffspecSimulation::~OffspecSimulation() override=default
OffspecSimulation::~OffspecSimulation";

%feature("docstring")  OffspecSimulation::className "std::string OffspecSimulation::className() const final
OffspecSimulation::className";

%feature("docstring")  OffspecSimulation::setBeamParameters "void OffspecSimulation::setBeamParameters(double wavelength, const IAxis &alpha_axis, double phi_i)
OffspecSimulation::setBeamParameters
Sets beam parameters from here (forwarded to Instrument) 
";

%feature("docstring")  OffspecSimulation::beamAxis "const IAxis * OffspecSimulation::beamAxis() const
OffspecSimulation::beamAxis
Returns axis of the beam. 
";

%feature("docstring")  OffspecSimulation::createCoordSystem "ICoordSystem * OffspecSimulation::createCoordSystem() const override
OffspecSimulation::createCoordSystem";


// File: classParticleLayoutContribution.xml
%feature("docstring") ParticleLayoutContribution "

Computes the scattering contribution from one particle layout. Instances are created and used by  DWBAComputation.

C++ includes: ParticleLayoutContribution.h
";

%feature("docstring")  ParticleLayoutContribution::ParticleLayoutContribution "ParticleLayoutContribution::ParticleLayoutContribution(const ReLayout &re_layout, const SimulationOptions &options, bool polarized)
ParticleLayoutContribution::ParticleLayoutContribution";

%feature("docstring")  ParticleLayoutContribution::~ParticleLayoutContribution "ParticleLayoutContribution::~ParticleLayoutContribution()
ParticleLayoutContribution::~ParticleLayoutContribution";

%feature("docstring")  ParticleLayoutContribution::compute "void ParticleLayoutContribution::compute(DiffuseElement &ele) const
ParticleLayoutContribution::compute";


// File: classPoissonBackground.xml
%feature("docstring") PoissonBackground "

Poisson distributed noise, to be added to simulated scattering.

C++ includes: PoissonBackground.h
";

%feature("docstring")  PoissonBackground::PoissonBackground "PoissonBackground::PoissonBackground()
PoissonBackground::PoissonBackground";

%feature("docstring")  PoissonBackground::clone "PoissonBackground * PoissonBackground::clone() const override
PoissonBackground::clone";

%feature("docstring")  PoissonBackground::className "std::string PoissonBackground::className() const final
PoissonBackground::className";

%feature("docstring")  PoissonBackground::addBackground "double PoissonBackground::addBackground(double intensity) const override
PoissonBackground::addBackground";


// File: classPoissonLikeMetric.xml
%feature("docstring") PoissonLikeMetric "

Implementation of  $ \\\\chi^2 $ metric with standard deviation  $\\\\sigma = max(\\\\sqrt{I}, 1)$, where  $I$ is the simulated intensity. With default L2 norm corresponds to the formula  \\\\[\\\\chi^2 = \\\\sum \\\\frac{(I - D)^2}{max(I, 1)}\\\\] for unweighted experimental data. Falls to standard  Chi2Metric when data uncertainties are taken into account.

C++ includes: ObjectiveMetric.h
";

%feature("docstring")  PoissonLikeMetric::PoissonLikeMetric "PoissonLikeMetric::PoissonLikeMetric()
PoissonLikeMetric::PoissonLikeMetric";

%feature("docstring")  PoissonLikeMetric::clone "PoissonLikeMetric * PoissonLikeMetric::clone() const override
PoissonLikeMetric::clone";

%feature("docstring")  PoissonLikeMetric::computeFromArrays "double PoissonLikeMetric::computeFromArrays(std::vector< double > sim_data, std::vector< double > exp_data, std::vector< double > weight_factors) const override
PoissonLikeMetric::computeFromArrays
Computes metric value from data arrays. Negative values in exp_data are ignored as well as non-positive weight_factors. All arrays involved in the computation must be of the same size.

Parameters:
-----------

sim_data: 
array with simulated intensities.

exp_data: 
array with intensity values obtained from an experiment.

weight_factors: 
user-defined weighting factors. Used linearly, no matter which norm is chosen. 
";

%feature("docstring")  PoissonLikeMetric::computeFromArrays "double Chi2Metric::computeFromArrays(std::vector< double > sim_data, std::vector< double > exp_data, std::vector< double > exp_stdv, std::vector< double > weight_factors) const override
PoissonLikeMetric::computeFromArrays
Computes metric value from data arrays. Negative values in exp_data are ignored as well as non-positive weight_factors and uncertainties. All arrays involved in the computation must be of the same size.

Parameters:
-----------

sim_data: 
array with simulated intensities.

exp_data: 
array with intensity values obtained from an experiment.

exp_stdv: 
array with experimental data uncertainties.

weight_factors: 
user-defined weighting factors. Used linearly, no matter which norm is chosen. 
";

%feature("docstring")  PoissonLikeMetric::computeFromArrays "double Chi2Metric::computeFromArrays(std::vector< double > sim_data, std::vector< double > exp_data, std::vector< double > weight_factors) const override
PoissonLikeMetric::computeFromArrays
Computes metric value from data arrays. Negative values in exp_data are ignored as well as non-positive weight_factors. All arrays involved in the computation must be of the same size.

Parameters:
-----------

sim_data: 
array with simulated intensities.

exp_data: 
array with intensity values obtained from an experiment.

weight_factors: 
user-defined weighting factors. Used linearly, no matter which norm is chosen. 
";


// File: classPyBuilderCallback.xml
%feature("docstring") PyBuilderCallback "

Builds simulation object using a Python callable. Base class to wrap Python callable and pass it to C++. Used in swig interface file, intended to be overloaded from Python.

C++ includes: PyFittingCallbacks.h
";

%feature("docstring")  PyBuilderCallback::PyBuilderCallback "PyBuilderCallback::PyBuilderCallback()
PyBuilderCallback::PyBuilderCallback";

%feature("docstring")  PyBuilderCallback::~PyBuilderCallback "PyBuilderCallback::~PyBuilderCallback()
PyBuilderCallback::~PyBuilderCallback";

%feature("docstring")  PyBuilderCallback::build_simulation "ISimulation * PyBuilderCallback::build_simulation(const mumufit::Parameters &) const
PyBuilderCallback::build_simulation";


// File: classPyObserverCallback.xml
%feature("docstring") PyObserverCallback "

Observer for  FitObjective based on Python callable. Base class to wrap Python callable and pass it to C++. Used in swig interface file, intended to be overloaded from Python.

C++ includes: PyFittingCallbacks.h
";

%feature("docstring")  PyObserverCallback::PyObserverCallback "PyObserverCallback::PyObserverCallback()
PyObserverCallback::PyObserverCallback";

%feature("docstring")  PyObserverCallback::~PyObserverCallback "PyObserverCallback::~PyObserverCallback()
PyObserverCallback::~PyObserverCallback";

%feature("docstring")  PyObserverCallback::update "void PyObserverCallback::update(const FitObjective &)
PyObserverCallback::update";


// File: classQzScan.xml
%feature("docstring") QzScan "

Scan type with z-components of scattering vector as coordinate values. Wavelength and incident angles are not accessible separately.

C++ includes: QzScan.h
";

%feature("docstring")  QzScan::QzScan "QzScan::QzScan(std::vector< double > qs_nm)
QzScan::QzScan
Accepts qz-value vector (in inverse nm) 
";

%feature("docstring")  QzScan::QzScan "QzScan::QzScan(const IAxis &qs_nm)
QzScan::QzScan";

%feature("docstring")  QzScan::QzScan "QzScan::QzScan(int nbins, double qz_min, double qz_max)
QzScan::QzScan
Sets q-defined specular scan. Accepts either numpy array of q-values sorted in ascending order or an IAxis object with q-values. Alternatively an axis can be defined in-place, then the first passed parameter is the number of bins, second - minimum on-axis q-value, third - maximum on-axis q_value. 
";

%feature("docstring")  QzScan::~QzScan "QzScan::~QzScan() override
QzScan::~QzScan";

%feature("docstring")  QzScan::clone "QzScan * QzScan::clone() const override
QzScan::clone";

%feature("docstring")  QzScan::resolution "const ScanResolution * QzScan::resolution() const
QzScan::resolution";

%feature("docstring")  QzScan::wavelength "double QzScan::wavelength() const override
QzScan::wavelength";

%feature("docstring")  QzScan::generateElements "std::vector< SpecularElement > QzScan::generateElements() const override
QzScan::generateElements
Generates simulation elements for specular simulations. 
";

%feature("docstring")  QzScan::coordinateAxis "const IAxis * QzScan::coordinateAxis() const override
QzScan::coordinateAxis
Returns coordinate axis assigned to the data holder. 
";

%feature("docstring")  QzScan::footprintFactor "const IFootprintFactor * QzScan::footprintFactor() const override
QzScan::footprintFactor
Returns IFootprintFactor object pointer. 
";

%feature("docstring")  QzScan::footprint "std::vector< double > QzScan::footprint(size_t i, size_t n_elements) const override
QzScan::footprint
Returns footprint correction factor for a range of simulation elements of size  n_elements and starting from element with index  i. 
";

%feature("docstring")  QzScan::numberOfElements "size_t QzScan::numberOfElements() const override
QzScan::numberOfElements
Returns the number of simulation elements. 
";

%feature("docstring")  QzScan::createCoordSystem "CoordSystem1D * QzScan::createCoordSystem() const override
QzScan::createCoordSystem";

%feature("docstring")  QzScan::createIntensities "std::vector< double > QzScan::createIntensities(const std::vector< SpecularElement > &eles) const override
QzScan::createIntensities
Returns intensity vector corresponding to convolution of given simulation elements. 
";

%feature("docstring")  QzScan::setQResolution "void QzScan::setQResolution(const ScanResolution &resolution)
QzScan::setQResolution
Sets q resolution values via  ScanResolution object. 
";

%feature("docstring")  QzScan::setRelativeQResolution "void QzScan::setRelativeQResolution(const IRangedDistribution &distr, double rel_dev)
QzScan::setRelativeQResolution";

%feature("docstring")  QzScan::setRelativeQResolution "void QzScan::setRelativeQResolution(const IRangedDistribution &distr, const std::vector< double > &rel_dev)
QzScan::setRelativeQResolution
Sets qz resolution values via IRangedDistribution and values of relative deviations (that is,  rel_dev equals standard deviation divided by the mean value).  rel_dev can be either single-valued or a numpy array. In the latter case the length of the array should coinside with the length of the qz-axis. 
";

%feature("docstring")  QzScan::setAbsoluteQResolution "void QzScan::setAbsoluteQResolution(const IRangedDistribution &distr, double std_dev)
QzScan::setAbsoluteQResolution";

%feature("docstring")  QzScan::setAbsoluteQResolution "void QzScan::setAbsoluteQResolution(const IRangedDistribution &distr, const std::vector< double > &std_dev)
QzScan::setAbsoluteQResolution
Sets qz resolution values via IRangedDistribution and values of standard deviations.  std_dev can be either single-valued or a numpy array. In the latter case the length of the array should coinside with the length of the qz-axis. 
";

%feature("docstring")  QzScan::setOffset "void QzScan::setOffset(double offset)
QzScan::setOffset";

%feature("docstring")  QzScan::offset "double QzScan::offset() const
QzScan::offset";


// File: classRoughMultiLayerContribution.xml
%feature("docstring") RoughMultiLayerContribution "

Computes the diffuse reflection from the rough interfaces of a sample. Used by  DWBAComputation.

C++ includes: RoughMultiLayerContribution.h
";

%feature("docstring")  RoughMultiLayerContribution::RoughMultiLayerContribution "RoughMultiLayerContribution::RoughMultiLayerContribution(const ReSample &re_sample)
RoughMultiLayerContribution::RoughMultiLayerContribution";

%feature("docstring")  RoughMultiLayerContribution::compute "void RoughMultiLayerContribution::compute(DiffuseElement &ele) const
RoughMultiLayerContribution::compute";


// File: classRQ4Metric.xml
%feature("docstring") RQ4Metric "

Implementation of relative difference metric. With default L2 norm and weighting off corresponds to the formula  \\\\[Result = \\\\sum (I \\\\cdot Q^4 - D \\\\cdot Q^4)^2\\\\] where  $Q$ is the scattering vector magnitude. If weighting is on, coincides with the metric provided by  Chi2Metric class.

C++ includes: ObjectiveMetric.h
";

%feature("docstring")  RQ4Metric::RQ4Metric "RQ4Metric::RQ4Metric()
RQ4Metric::RQ4Metric";

%feature("docstring")  RQ4Metric::clone "RQ4Metric * RQ4Metric::clone() const override
RQ4Metric::clone";

%feature("docstring")  RQ4Metric::compute "double RQ4Metric::compute(const SimDataPair &data_pair, bool use_weights) const override
RQ4Metric::compute
Computes metric value from  SimDataPair object. Calls computeFromArrays internally.

Parameters:
-----------

data_pair: 
 SimDataPair object. Can optionally contain data uncertainties

use_weights: 
boolean, defines if data uncertainties should be taken into account 
";


// File: classSampleToPython.xml
%feature("docstring") SampleToPython "

Generates Python code snippet from domain (C++) objects representing sample construction.

C++ includes: SampleToPython.h
";

%feature("docstring")  SampleToPython::SampleToPython "SampleToPython::SampleToPython()
SampleToPython::SampleToPython";

%feature("docstring")  SampleToPython::~SampleToPython "SampleToPython::~SampleToPython()
SampleToPython::~SampleToPython";

%feature("docstring")  SampleToPython::sampleCode "std::string SampleToPython::sampleCode(const MultiLayer &sample)
SampleToPython::sampleCode";


// File: classScanResolution.xml
%feature("docstring") ScanResolution "

Container for reflectivity resolution data.

C++ includes: ScanResolution.h
";

%feature("docstring")  ScanResolution::~ScanResolution "ScanResolution::~ScanResolution() override
ScanResolution::~ScanResolution";

%feature("docstring")  ScanResolution::clone "ScanResolution * ScanResolution::clone() const override=0
ScanResolution::clone";

%feature("docstring")  ScanResolution::distribution "const IRangedDistribution * ScanResolution::distribution() const
ScanResolution::distribution";

%feature("docstring")  ScanResolution::nSamples "size_t ScanResolution::nSamples() const
ScanResolution::nSamples";

%feature("docstring")  ScanResolution::generateSamples "virtual DistrOutput ScanResolution::generateSamples(double mean, size_t n_times) const =0
ScanResolution::generateSamples";

%feature("docstring")  ScanResolution::generateSamples "virtual DistrOutput ScanResolution::generateSamples(const std::vector< double > &mean) const =0
ScanResolution::generateSamples";

%feature("docstring")  ScanResolution::stdDevs "virtual std::vector< double > ScanResolution::stdDevs(double mean, size_t n_times) const =0
ScanResolution::stdDevs";

%feature("docstring")  ScanResolution::stdDevs "virtual std::vector< double > ScanResolution::stdDevs(const std::vector< double > &mean) const =0
ScanResolution::stdDevs";

%feature("docstring")  ScanResolution::empty "bool ScanResolution::empty() const
ScanResolution::empty";

%feature("docstring")  ScanResolution::name "virtual std::string ScanResolution::name() const =0
ScanResolution::name";

%feature("docstring")  ScanResolution::delta "virtual double ScanResolution::delta() const =0
ScanResolution::delta";


// File: classScatteringSimulation.xml
%feature("docstring") ScatteringSimulation "

GISAS simulation.

Holds an instrument and sample model. Computes the scattered intensity as function of 2D detector coordinates.

C++ includes: ScatteringSimulation.h
";

%feature("docstring")  ScatteringSimulation::ScatteringSimulation "ScatteringSimulation::ScatteringSimulation(const Beam &beam, const MultiLayer &sample, const IDetector &detector)
ScatteringSimulation::ScatteringSimulation";

%feature("docstring")  ScatteringSimulation::~ScatteringSimulation "ScatteringSimulation::~ScatteringSimulation() override=default
ScatteringSimulation::~ScatteringSimulation";

%feature("docstring")  ScatteringSimulation::className "std::string ScatteringSimulation::className() const final
ScatteringSimulation::className";

%feature("docstring")  ScatteringSimulation::createCoordSystem "ICoordSystem * ScatteringSimulation::createCoordSystem() const override
ScatteringSimulation::createCoordSystem";


// File: classSimDataPair.xml
%feature("docstring") SimDataPair "

Holds pair of simulation/experimental data to fit.

C++ includes: SimDataPair.h
";

%feature("docstring")  SimDataPair::SimDataPair "SimDataPair::SimDataPair(simulation_builder_t builder, const Datafield &raw_data, std::unique_ptr< Datafield > &&raw_stdv, double user_weight=1.0)
SimDataPair::SimDataPair";

%feature("docstring")  SimDataPair::SimDataPair "SimDataPair::SimDataPair(simulation_builder_t builder, const Datafield &raw_data, std::unique_ptr< Datafield > &&raw_stdv, std::unique_ptr< Datafield > &&user_weights)
SimDataPair::SimDataPair";

%feature("docstring")  SimDataPair::SimDataPair "SimDataPair::SimDataPair(SimDataPair &&other)
SimDataPair::SimDataPair";

%feature("docstring")  SimDataPair::~SimDataPair "SimDataPair::~SimDataPair()
SimDataPair::~SimDataPair";

%feature("docstring")  SimDataPair::execSimulation "void SimDataPair::execSimulation(const mumufit::Parameters &params)
SimDataPair::execSimulation";

%feature("docstring")  SimDataPair::containsUncertainties "bool SimDataPair::containsUncertainties() const
SimDataPair::containsUncertainties";

%feature("docstring")  SimDataPair::simulationResult "SimulationResult SimDataPair::simulationResult() const
SimDataPair::simulationResult
Returns the result of last computed simulation. 
";

%feature("docstring")  SimDataPair::experimentalData "SimulationResult SimDataPair::experimentalData() const
SimDataPair::experimentalData
Returns the experimental data cut to the ROI area. 
";

%feature("docstring")  SimDataPair::uncertainties "SimulationResult SimDataPair::uncertainties() const
SimDataPair::uncertainties
Returns the data uncertainties cut to the ROI area If no uncertainties present, returns zero-filled SimulationResult. 
";

%feature("docstring")  SimDataPair::userWeights "SimulationResult SimDataPair::userWeights() const
SimDataPair::userWeights
Returns the user uncertainties cut to the ROI area. 
";

%feature("docstring")  SimDataPair::relativeDifference "SimulationResult SimDataPair::relativeDifference() const
SimDataPair::relativeDifference
Returns relative difference between simulation and experimental data.

Returns the relative difference between simulated and experimental data cut to the ROI area 
";

%feature("docstring")  SimDataPair::absoluteDifference "SimulationResult SimDataPair::absoluteDifference() const
SimDataPair::absoluteDifference
Returns the absolute difference between simulated and experimental data cut to the ROI area 
";

%feature("docstring")  SimDataPair::simulation_array "std::vector< double > SimDataPair::simulation_array() const
SimDataPair::simulation_array
Returns the flattened simulated intensities cut to the ROI area. 
";

%feature("docstring")  SimDataPair::experimental_array "std::vector< double > SimDataPair::experimental_array() const
SimDataPair::experimental_array
Returns the flattened experimental data cut to the ROI area. 
";

%feature("docstring")  SimDataPair::uncertainties_array "std::vector< double > SimDataPair::uncertainties_array() const
SimDataPair::uncertainties_array
Returns the flattened experimental uncertainties cut to the ROI area. If no uncertainties are available, Returns a zero-filled array sized to the ROI area. 
";

%feature("docstring")  SimDataPair::user_weights_array "std::vector< double > SimDataPair::user_weights_array() const
SimDataPair::user_weights_array
Returns a flat array of user weights cut to the ROI area. 
";


// File: classSimulationToPython.xml
%feature("docstring") SimulationToPython "

Write a Python script that allows to run the current simulation.

C++ includes: SimulationToPython.h
";

%feature("docstring")  SimulationToPython::simulationPlotCode "std::string SimulationToPython::simulationPlotCode(const ISimulation &simulation)
SimulationToPython::simulationPlotCode
Returns a Python script that runs a simulation and plots the result. 
";

%feature("docstring")  SimulationToPython::simulationSaveCode "std::string SimulationToPython::simulationSaveCode(const ISimulation &simulation, const std::string &fname)
SimulationToPython::simulationSaveCode
Returns a Python script that runs a simulation and saves the result to a file. 
";


// File: classSpecularComputation.xml
%feature("docstring") SpecularComputation "

Performs a single-threaded specular computation with given sample.

Controlled by the multi-threading machinery in ISimulation::runSingleSimulation().

C++ includes: SpecularComputation.h
";

%feature("docstring")  SpecularComputation::SpecularComputation "SpecularComputation::SpecularComputation(const ReSample &re_sample, const SimulationOptions &options, ProgressHandler &progress, SpecularElementIter begin_it, SpecularElementIter end_it)
SpecularComputation::SpecularComputation";

%feature("docstring")  SpecularComputation::~SpecularComputation "SpecularComputation::~SpecularComputation() override
SpecularComputation::~SpecularComputation";


// File: classSpecularSimulation.xml
%feature("docstring") SpecularSimulation "

Specular reflectometry simulation.

Holds an instrument and sample model. Computes detected intensity as function of the glancing angles alpha_i=alpha_f.

C++ includes: SpecularSimulation.h
";

%feature("docstring")  SpecularSimulation::SpecularSimulation "SpecularSimulation::SpecularSimulation(const ISpecularScan &scan, const MultiLayer &sample)
SpecularSimulation::SpecularSimulation";

%feature("docstring")  SpecularSimulation::~SpecularSimulation "SpecularSimulation::~SpecularSimulation() override
SpecularSimulation::~SpecularSimulation";

%feature("docstring")  SpecularSimulation::SpecularSimulation "SpecularSimulation::SpecularSimulation(SpecularSimulation &&)
SpecularSimulation::SpecularSimulation";

%feature("docstring")  SpecularSimulation::className "std::string SpecularSimulation::className() const final
SpecularSimulation::className";

%feature("docstring")  SpecularSimulation::force_polarized "bool SpecularSimulation::force_polarized() const override
SpecularSimulation::force_polarized
Force polarized computation even in absence of sample magnetization or external fields. 
";

%feature("docstring")  SpecularSimulation::prepareSimulation "void SpecularSimulation::prepareSimulation() override
SpecularSimulation::prepareSimulation
Put into a clean state for running a simulation. 
";

%feature("docstring")  SpecularSimulation::createCoordSystem "ICoordSystem * SpecularSimulation::createCoordSystem() const override
SpecularSimulation::createCoordSystem";

%feature("docstring")  SpecularSimulation::scan "const ISpecularScan * SpecularSimulation::scan() const
SpecularSimulation::scan
Returns internal data handler. 
";


// File: classVarianceConstantFunction.xml
%feature("docstring") VarianceConstantFunction "

Returns 1.0 as variance value

C++ includes: VarianceFunctions.h
";

%feature("docstring")  VarianceConstantFunction::clone "VarianceConstantFunction * VarianceConstantFunction::clone() const override
VarianceConstantFunction::clone";

%feature("docstring")  VarianceConstantFunction::variance "double VarianceConstantFunction::variance(double, double) const override
VarianceConstantFunction::variance";


// File: classVarianceSimFunction.xml
%feature("docstring") VarianceSimFunction "

Returns max(sim, epsilon)

C++ includes: VarianceFunctions.h
";

%feature("docstring")  VarianceSimFunction::VarianceSimFunction "VarianceSimFunction::VarianceSimFunction(double epsilon=1.0)
VarianceSimFunction::VarianceSimFunction";

%feature("docstring")  VarianceSimFunction::clone "VarianceSimFunction * VarianceSimFunction::clone() const override
VarianceSimFunction::clone";

%feature("docstring")  VarianceSimFunction::variance "double VarianceSimFunction::variance(double exp, double sim) const override
VarianceSimFunction::variance";


// File: namespace_0d17.xml


// File: namespace_0d19.xml


// File: namespace_0d31.xml


// File: namespace_0d33.xml


// File: namespace_0d35.xml


// File: namespace_0d38.xml


// File: namespace_0d45.xml


// File: namespace_0d47.xml


// File: namespace_0d51.xml


// File: namespace_0d61.xml


// File: namespace_0d67.xml


// File: namespace_0d69.xml


// File: namespace_0d72.xml


// File: namespace_0d9.xml


// File: namespacemumufit.xml


// File: namespaceObjectiveMetricUtils.xml
%feature("docstring")  ObjectiveMetricUtils::l1Norm "std::function< double(double)> ObjectiveMetricUtils::l1Norm()
ObjectiveMetricUtils::l1Norm
Returns L1 normalization function. 
";

%feature("docstring")  ObjectiveMetricUtils::l2Norm "std::function< double(double)> ObjectiveMetricUtils::l2Norm()
ObjectiveMetricUtils::l2Norm
Returns L2 normalization function. 
";

%feature("docstring")  ObjectiveMetricUtils::createMetric "std::unique_ptr< ObjectiveMetric > ObjectiveMetricUtils::createMetric(const std::string &metric)
ObjectiveMetricUtils::createMetric
Creates the specified metric with the default norm. 
";

%feature("docstring")  ObjectiveMetricUtils::createMetric "std::unique_ptr< ObjectiveMetric > ObjectiveMetricUtils::createMetric(std::string metric, std::string norm)
ObjectiveMetricUtils::createMetric
Creates the metric with the specified norm. 
";

%feature("docstring")  ObjectiveMetricUtils::availableMetricOptions "std::string ObjectiveMetricUtils::availableMetricOptions()
ObjectiveMetricUtils::availableMetricOptions
Prints available metric options. 
";

%feature("docstring")  ObjectiveMetricUtils::normNames "std::vector< std::string > ObjectiveMetricUtils::normNames()
ObjectiveMetricUtils::normNames
Returns the names of the norms used by  ObjectiveMetric. 
";

%feature("docstring")  ObjectiveMetricUtils::metricNames "std::vector< std::string > ObjectiveMetricUtils::metricNames()
ObjectiveMetricUtils::metricNames
Returns the names of the objective metrics used. 
";

%feature("docstring")  ObjectiveMetricUtils::defaultNormName "std::string ObjectiveMetricUtils::defaultNormName()
ObjectiveMetricUtils::defaultNormName
Returns default norm name. 
";

%feature("docstring")  ObjectiveMetricUtils::defaultMetricName "std::string ObjectiveMetricUtils::defaultMetricName()
ObjectiveMetricUtils::defaultMetricName
Returns default metric name. 
";


// File: namespacePy.xml


// File: namespacePy_1_1Export.xml
%feature("docstring")  Py::Export::sampleCode "std::string Py::Export::sampleCode(const MultiLayer &sample)
Py::Export::sampleCode";

%feature("docstring")  Py::Export::simulationPlotCode "std::string Py::Export::simulationPlotCode(const ISimulation &simulation)
Py::Export::simulationPlotCode";

%feature("docstring")  Py::Export::simulationSaveCode "std::string Py::Export::simulationSaveCode(const ISimulation &simulation, const std::string &fname)
Py::Export::simulationSaveCode";


// File: namespacePy_1_1Fmt.xml
%feature("docstring")  Py::Fmt::printRealLimits "std::string Py::Fmt::printRealLimits(const RealLimits &limits, const std::string &units)
Py::Fmt::printRealLimits";

%feature("docstring")  Py::Fmt::printRealLimitsArg "std::string Py::Fmt::printRealLimitsArg(const RealLimits &limits, const std::string &units)
Py::Fmt::printRealLimitsArg
Prints RealLimits in the form of argument (in the context of ParameterDistribution and similar). Default RealLimits will not be printed, any other will be printed as \", ba.RealLimits.limited(1*deg, 2*deg)\" 
";


// File: namespacePy_1_1Fmt2.xml
%feature("docstring")  Py::Fmt2::representShape2D "std::string Py::Fmt2::representShape2D(const std::string &indent, const IShape2D *ishape, bool mask_value, std::function< std::string(double)> printValueFunc)
Py::Fmt2::representShape2D
Returns fixed Python code snippet that defines the function \"simulate\". 
";

%feature("docstring")  Py::Fmt2::printAxis "std::string Py::Fmt2::printAxis(const IAxis *axis, const std::string &unit)
Py::Fmt2::printAxis
Prints an axis. 
";

%feature("docstring")  Py::Fmt2::printParameterDistribution "std::string Py::Fmt2::printParameterDistribution(const ParameterDistribution &par_distr, const std::string &distVarName, const std::string &units)
Py::Fmt2::printParameterDistribution";

%feature("docstring")  Py::Fmt2::printRangedDistribution "std::string Py::Fmt2::printRangedDistribution(const IRangedDistribution &distr)
Py::Fmt2::printRangedDistribution";


// File: ConstantBackground_8cpp.xml


// File: ConstantBackground_8h.xml


// File: IBackground_8cpp.xml


// File: IBackground_8h.xml


// File: PoissonBackground_8cpp.xml


// File: PoissonBackground_8h.xml


// File: ComputationStatus_8h.xml


// File: DepthProbeComputation_8cpp.xml


// File: DepthProbeComputation_8h.xml


// File: DWBAComputation_8cpp.xml


// File: DWBAComputation_8h.xml


// File: IComputation_8cpp.xml


// File: IComputation_8h.xml


// File: SpecularComputation_8cpp.xml


// File: SpecularComputation_8h.xml


// File: GISASSpecularContribution_8cpp.xml


// File: GISASSpecularContribution_8h.xml


// File: ParticleLayoutContribution_8cpp.xml


// File: ParticleLayoutContribution_8h.xml


// File: RoughMultiLayerContribution_8cpp.xml


// File: RoughMultiLayerContribution_8h.xml


// File: ComponentKeyHandler_8cpp.xml


// File: ComponentKeyHandler_8h.xml


// File: ExportToPython_8cpp.xml


// File: ExportToPython_8h.xml


// File: MaterialKeyHandler_8cpp.xml


// File: MaterialKeyHandler_8h.xml


// File: PyFmt2_8cpp.xml


// File: PyFmt2_8h.xml


// File: PyFmtLimits_8cpp.xml


// File: PyFmtLimits_8h.xml


// File: SampleToPython_8cpp.xml


// File: SampleToPython_8h.xml


// File: SimulationToPython_8cpp.xml


// File: SimulationToPython_8h.xml


// File: FitObjective_8cpp.xml


// File: FitObjective_8h.xml


// File: FitObserver_8h.xml


// File: FitPrintService_8cpp.xml


// File: FitPrintService_8h.xml


// File: FitStatus_8cpp.xml


// File: FitStatus_8h.xml


// File: FitTypes_8h.xml


// File: IterationInfo_8cpp.xml


// File: IterationInfo_8h.xml


// File: ObjectiveMetric_8cpp.xml


// File: ObjectiveMetric_8h.xml


// File: ObjectiveMetricUtils_8cpp.xml


// File: ObjectiveMetricUtils_8h.xml


// File: PyFittingCallbacks_8cpp.xml


// File: PyFittingCallbacks_8h.xml


// File: SimDataPair_8cpp.xml


// File: SimDataPair_8h.xml


// File: ChiSquaredModule_8cpp.xml


// File: ChiSquaredModule_8h.xml


// File: IChiSquaredModule_8cpp.xml


// File: IChiSquaredModule_8h.xml


// File: IIntensityFunction_8cpp.xml


// File: IIntensityFunction_8h.xml


// File: VarianceFunctions_8cpp.xml


// File: VarianceFunctions_8h.xml


// File: AlphaScan_8cpp.xml


// File: AlphaScan_8h.xml


// File: ISpecularScan_8cpp.xml


// File: ISpecularScan_8h.xml


// File: QzScan_8cpp.xml


// File: QzScan_8h.xml


// File: ScanResolution_8cpp.xml


// File: ScanResolution_8h.xml


// File: DepthProbeSimulation_8cpp.xml


// File: DepthProbeSimulation_8h.xml


// File: includeSimulations_8h.xml


// File: ISimulation_8cpp.xml


// File: ISimulation_8h.xml


// File: ISimulation2D_8cpp.xml


// File: ISimulation2D_8h.xml


// File: OffspecSimulation_8cpp.xml


// File: OffspecSimulation_8h.xml


// File: ScatteringSimulation_8cpp.xml


// File: ScatteringSimulation_8h.xml


// File: SpecularSimulation_8cpp.xml


// File: SpecularSimulation_8h.xml


// File: dir_69622bdd5740149fae063934074f5b46.xml


// File: dir_80b5fc9f893426fd5fb9fe1745a013f9.xml


// File: dir_84c420b536327f5f78c313c975fc3e9e.xml


// File: dir_2f33233fd7f1d04aa5b1f43b1305dab7.xml


// File: dir_cf99511bd3a2a600b8765d13a2b8e763.xml


// File: dir_a7a79cf6fe55455f4aa40bf75f4a8347.xml


// File: dir_b1fb6e3aebde3102cfb6ed4db3ad7376.xml


// File: dir_45c35af18c2a9ebb0bbd91b9bd7680de.xml


// File: dir_4d66887e6a4aee2bb3ce63737017e0ad.xml

